@@ -2,7 +2,11 @@ from openfisca_core.taxbenefitsystems import TaxBenefitSystem
 from openfisca_us.entities import *
 from openfisca_us.parameters.irs.uprating import set_irs_uprating_parameter
 from openfisca_us.situation_examples import single_filer
-from openfisca_tools import homogenize_parameter_structures, uprate_parameters
+from openfisca_tools import (
+    homogenize_parameter_structures,
+    uprate_parameters,
+    propagate_parameter_metadata,
+)
 import os
 
 COUNTRY_DIR = os.path.dirname(os.path.abspath(__file__))
@@ -30,6 +34,8 @@ class CountryTaxBenefitSystem(TaxBenefitSystem):
             self.parameters, self.variables
         )
 
+        self.parameters = propagate_parameter_metadata(self.parameters)
+
         self.parameters = set_irs_uprating_parameter(self.parameters)
 
         self.parameters = uprate_parameters(self.parameters)
